@@ -1,4 +1,4 @@
-/* $Id: actions.c,v 1.34 2011/10/15 22:24:51 imilh Exp $ */
+/* $Id: actions.c,v 1.38 2011/10/23 13:47:03 imilh Exp $ */
 
 /*
  * Copyright (c) 2009, 2010, 2011 The NetBSD Foundation, Inc.
@@ -407,8 +407,13 @@ pkgin_install(char **opkgargs, uint8_t do_inst)
 			pkgin_cache, pimpact->full, PKG_EXT);
 
 		/* if package is not already downloaded or size mismatch, d/l it */
-		if (stat(pkgpath, &st) < 0 || st.st_size != pimpact->file_size)
-			file_size += pimpact->file_size;
+		if ((stat(pkgpath, &st) < 0 || st.st_size != pimpact->file_size) &&
+			/* don't update file_size if repo is file:// */
+			strncmp(pkgpath, SCHEME_FILE, strlen(SCHEME_FILE) != 0))
+				file_size += pimpact->file_size;
+
+		if (pimpact->old_size_pkg > 0)
+			pimpact->size_pkg -= pimpact->old_size_pkg;
 
 		size_pkg += pimpact->size_pkg;
 
@@ -513,7 +518,7 @@ pkgin_install(char **opkgargs, uint8_t do_inst)
 
 				/* pure install, not called by pkgin_upgrade */
 				if (upgrade_type == UPGRADE_NONE)
-					update_db(LOCAL_SUMMARY, pkgargs);
+					(void)update_db(LOCAL_SUMMARY, pkgargs);
 				
 				rc = EXIT_SUCCESS;
 			}
@@ -607,7 +612,7 @@ pkgin_remove(char **pkgargs)
 		if (check_yesno(DEFAULT_YES)) {
 			do_pkg_remove(removehead);
 
-			update_db(LOCAL_SUMMARY, NULL);
+			(void)update_db(LOCAL_SUMMARY, NULL);
 
 			rc = EXIT_SUCCESS;
 		} else
@@ -723,7 +728,7 @@ pkgin_upgrade(int uptype)
 			pkgargs = record_upgrades(keeplisthead);
 		}
 
-		update_db(LOCAL_SUMMARY, pkgargs);
+		(void)update_db(LOCAL_SUMMARY, pkgargs);
 	}
 
 	free_list(pkgargs);
