@@ -1,4 +1,4 @@
-/* $Id: pkgin.h,v 1.25 2011/10/10 13:06:37 imilh Exp $ */
+/* $Id: pkgin.h,v 1.28 2011/10/23 13:47:03 imilh Exp $ */
 
 /*
  * Copyright (c) 2009, 2010 The NetBSD Foundation, Inc.
@@ -154,6 +154,7 @@ typedef struct Pkglist {
 	uint8_t	type; /*!< list type (LIST, DEPTREE or IMPACT) */
 
 	int64_t	size_pkg; /*!< installed package size (list and impact) */
+	int64_t old_size_pkg; /*!< old installed package size */
 	int64_t	file_size; /*!< binary package size */
 	int		level; /*<! recursion level (deptree and impact) */
 
@@ -204,14 +205,14 @@ extern FILE			*tracefp;
 /* download.c*/
 Dlfile		*download_file(char *, time_t *);
 /* summary.c */
-void		update_db(int, char **);
+int			update_db(int, char **);
 void		split_repos(void);
 /* sqlite_callbacks.c */
 int			pdb_rec_list(void *, int, char **, char **);
 int			pdb_rec_depends(void *, int, char **, char **);
 /* depends.c */
-void		show_direct_depends(const char *);
-void		show_full_dep_tree(const char *, const char *, const char *);
+int			show_direct_depends(const char *);
+int			show_full_dep_tree(const char *, const char *, const char *);
 void 		full_dep_tree(const char *pkgname, const char *depquery,
 	Plisthead	*pdphead);
 /* pkglist.c */
