@@ -1,4 +1,4 @@
-/* $Id: summary.c,v 1.18 2011/09/18 18:18:04 imilh Exp $ */
+/* $Id: summary.c,v 1.21 2011/10/23 13:57:56 imilh Exp $ */
 
 /*
  * Copyright (c) 2009, 2010 The NetBSD Foundation, Inc.
@@ -563,7 +563,7 @@ pdb_clean_remote(void *param, int argc, char **argv, char **colname)
 	return PDB_OK;
 }
 
-void
+int
 update_db(int which, char **pkgkeep)
 {
 	int			i;
@@ -571,6 +571,9 @@ update_db(int which, char **pkgkeep)
 	Pkglist		*pkglist;
 	char		**summary = NULL, **prepos, buf[BUFSIZ];
 
+	if (!have_enough_rights())
+		return EXIT_FAILURE;
+
 	for (i = 0; i < 2; i++) {
 
 		switch (sumsw[i].type) {
@@ -680,6 +683,7 @@ update_db(int which, char **pkgkeep)
 		freecols();
 	}
 
+	return EXIT_SUCCESS;
 }
 
 void
